@@ -25,7 +25,7 @@ parser_start.add_argument(
     help="Enter the name of the dataset to be used",
 )
 
-parser_start.add_argument("--split", default=0.001, help="Enter the split required")
+parser_start.add_argument("-s", "--split", default=0.001, help="Enter the split required")
 
 parser_start.add_argument(
     "-n", "--name", default="summarsiation", help="Enter the name of the model"
@@ -65,7 +65,7 @@ parser_pull = command_subparser.add_parser(
 parser_run = command_subparser.add_parser(
     "run",
     help="run the DVC pipeline - recompute any modified outputs such as "
-    "processed data or trained models",
+         "processed data or trained models",
 )
 
 parser_visualize = command_subparser.add_parser(
@@ -111,6 +111,28 @@ class Run(object):
             return list_files.returncode
         elif arguments["command"] == "start":
             os.chdir("./summarization/")
+            print("""
+            usage: t5s start [-h] [-d DATASET] [-s SPLIT] [-n NAME] [-mt MODEL_TYPE]
+                 [-m MODEL_NAME] [-e EPOCHS] [-lr LEARNING_RATE]
+                 [-b BATCH_SIZE]
+                 
+  -h, --help            show this help message and exit
+  -d DATASET, --dataset DATASET
+                        Enter the name of the dataset to be used
+  -s SPLIT, --split SPLIT
+                        Enter the split required
+  -n NAME, --name NAME  Enter the name of the model
+  -mt MODEL_TYPE, --model_type MODEL_TYPE
+                        Enter the model type
+  -m MODEL_NAME, --model_name MODEL_NAME
+                        Enter the model to be used eg t5-base
+  -e EPOCHS, --epochs EPOCHS
+                        Enter the number of epochs
+  -lr LEARNING_RATE, --learning-rate LEARNING_RATE
+                        Enter the number of epochs
+  -b BATCH_SIZE, --batch-size BATCH_SIZE
+                        Enter the number of batches
+            """)
             start(arguments=arguments)
         elif arguments["command"] in cmd:
             os.chdir("./summarization/")
